# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.repository.v1 import schema_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2


class SchemaStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.repository.v1.Schema/create',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.CreateSchemaRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.repository.v1.Schema/update',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.UpdateSchemaRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.repository.v1.Schema/delete',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.repository.v1.Schema/get',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.GetRepositorySchemaRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.repository.v1.Schema/list',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemasInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.repository.v1.Schema/stat',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class SchemaServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Schema. You must specify the parameters: `service_type`, `name`, and `schema`(data structure). With the parameter `domain_id`, you can choose whether you will create a Schema in `Local` or externally. The Schema created includes `repository_info`, information about where the resource is managed.
        request_example: >-
        {
        "name": "slack_webhook",
        "service_type": "secret.credentials",
        "schema": {},
        "labels": [],
        "tags": {
        "description": "Slack Webhook"
        },
        "domain_id": "domain-987654321098"
        }
        response_example: >-
        {
        "name": "slack_webhook",
        "service_type": "secret.credentials",
        "schema": {},
        "labels": [],
        "tags": {
        "description": "Slack Webhook"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2022-01-01T05:46:49.929Z",
        "updated_at": "2022-01-01T05:46:49.929Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Schema. You can make changes in Schema settings, including `name`, `schema`, `labels`, and `tags`.
        request_example: >-
        {
        "name": "slack_webhook_test",
        "schema": {},
        "labels": [],
        "tags": {},
        "domain_id": "domain-987654321098"
        }
        response_example: >-
        {
        "name": "slack_webhook_test",
        "service_type": "secret.credentials",
        "schema": {},
        "labels": [],
        "tags": {
        "description": "Slack Webhook"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2022-01-01T05:46:49.929Z",
        "updated_at": "2022-01-01T05:46:49.929Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Schema. You must specify the `name` of the Schema to delete, as the `name` is an identifier of Schema resources.
        request_example: >-
        {
        "name": "slack_webhook"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Schema. You must specify the `name` of the Schema to get, as the `name` is an identifier of Schema resources. You can use the parameter `repository_id` to limit the scope of the method to a specific Repository.
        request_example: >-
        {
        "name": "slack_webhook",
        "repository_id": "repo-123456789012"
        }
        response_example: >-
        {
        "name": "slack_webhook",
        "service_type": "secret.credentials",
        "schema": {},
        "labels": [],
        "tags": {
        "description": "Slack Webhook"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2022-01-01T10:20:09.064Z",
        "updated_at": "2022-01-01T10:20:09.064Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Schemas in a specific Repository. The parameter `repository_id` is used as an identifier of a Repository to get its list of Schemas. You can use a query to get a filtered list of Schemas.
        request_example: >-
        {
        "query": {},
        "name": "slack_webhook",
        "service_type": "secret.credentials",
        "repository_id": "repo-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "name": "slack_webhook",
        "service_type": "secret.credentials",
        "schema": {},
        "labels": [],
        "tags": {
        "description": "Slack Webhook"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Local",
        "repository_type": "local"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2022-01-01T10:20:09.064Z",
        "updated_at": "2022-01-01T10:20:09.064Z"
        }
        ],
        "total_count": 1
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SchemaServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.CreateSchemaRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.UpdateSchemaRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.GetRepositorySchemaRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemasInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.repository.v1.Schema', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Schema(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Schema/create',
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.CreateSchemaRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Schema/update',
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.UpdateSchemaRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Schema/delete',
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Schema/get',
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.GetRepositorySchemaRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Schema/list',
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaQuery.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemasInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Schema/stat',
            spaceone_dot_api_dot_repository_dot_v1_dot_schema__pb2.SchemaStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spaceone.api.monitoring.v1 import metric_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2


class MetricStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.list = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Metric/list',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricsInfo.FromString,
                )
        self.get_data = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Metric/get_data',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricDataRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricDataInfo.FromString,
                )


class MetricServicer(object):
    """Missing associated documentation comment in .proto file."""

    def list(self, request, context):
        """
        desc: Gets a list of all Metrics of one or more specified Resources. The parameter `resources` is a list of Resources from which to get a list of Metrics collected.
        request_example: >-
        {
        "data_source_id": "ds-31190a65a42a",
        "resources": ["cloud-svc-cd0105d255da"],
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "metrics": [
        {
        "key": "CPUUtilization",
        "group": "AWS/EC2",
        "name": "CPUUtilization",
        "unit": {
        "y": "Percent",
        "x": "Timestamp"
        },
        "metric_query": {
        "cloud-svc-cd0105d255da": {
        "Dimensions": [
        {
        "Name": "InstanceId",
        "Value": "i-0400cdd39f1a4d5e9"
        }
        ],
        "MetricName": "CPUUtilization",
        "Namespace": "AWS/EC2"
        }
        }
        },
        {
        "key": "NetworkIn",
        "group": "AWS/EC2",
        "name": "NetworkIn",
        "unit": {
        "y": "Bytes",
        "x": "Timestamp"
        },
        "metric_query": {
        "cloud-svc-cd0105d255da": {
        "Dimensions": [
        {
        "Name": "InstanceId",
        "Value": "i-0400cdd39f1a4d5e9"
        }
        ],
        "MetricName": "NetworkIn",
        "Namespace": "AWS/EC2"
        }
        }
        }
        ],
        "available_resources": {
        "cloud-svc-cd0105d255da": true
        },
        "domain_id": "domain-31190a65a42a"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_data(self, request, context):
        """
        desc: Gets data of a single Metric. You must specify the parameter `metric` to get data of. You can specify the `period` to get data for.
        request_example: >-
        {
        "data_source_id": "ds-31190a65a42a",
        "metric_query": {
        "cloud-svc-cd0105d255da": {
        "Dimensions": [
        {
        "Name": "InstanceId",
        "Value": "i-0400cdd39f1a4d5e9"
        }
        ],
        "MetricName": "CPUUtilization",
        "Namespace": "AWS/EC2"
        }
        },
        "metric": "CPUUtilization",
        "start": "2022-06-21T03:11:29.438Z",
        "end": "2022-06-21T04:11:29.438Z",
        "stat": "AVERAGE",
        "domain_id": "domain-58010aa2e451"
        }
        response_example: >-
        {
        "labels": [
        "2022-06-21T03:13:00.000Z",
        "2022-06-21T03:18:00.000Z",
        "2022-06-21T03:23:00.000Z",
        "2022-06-21T03:28:00.000Z",
        "2022-06-21T03:33:00.000Z",
        "2022-06-21T03:38:00.000Z",
        "2022-06-21T03:43:00.000Z",
        "2022-06-21T03:48:00.000Z",
        "2022-06-21T03:53:00.000Z",
        "2022-06-21T03:58:00.000Z",
        "2022-06-21T04:03:00.000Z",
        "2022-06-21T04:08:00.000Z"
        ],
        "resource_values": {
        "cloud-svc-cd0105d255da": [
        0.099999999999999,
        0.10001852366397981,
        0.10001852366397981,
        0.1328230362675432,
        0.099472075576548,
        0.06507936507936621,
        0.166703713994628,
        0.1338983050847476,
        0.1327868852458988,
        0.1339168287487284,
        0.1328610417160508,
        0.10056497175141618
        ]
        },
        "domain_id": "domain-58010aa2e451"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_MetricServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricsInfo.SerializeToString,
            ),
            'get_data': grpc.unary_unary_rpc_method_handler(
                    servicer.get_data,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricDataRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricDataInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.monitoring.v1.Metric', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Metric(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Metric/list',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_data(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Metric/get_data',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricDataRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_metric__pb2.MetricDataInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import collector_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2
from spaceone.api.inventory.v1 import job_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2


class JobStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.delete = channel.unary_unary(
                '/spaceone.api.inventory.v1.Job/delete',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.Job/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.GetJobRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.JobInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.Job/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobsQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.Job/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class JobServicer(object):
    """Missing associated documentation comment in .proto file."""

    def delete(self, request, context):
        """
        desc: Deletes a specific Job. You must specify the `job_id` of the Job to delete.
        request_example: >-
        {
        "job_id": "job-123456789012",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Job. Prints detailed information about the Job, including its state, total tasks, and collector info.
        request_example: >-
        {
        "job_id": "job-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "job_id": "job-123456789012",
        "status": "ERROR",
        "filter": {},
        "total_tasks": 2,
        "collector_info": {
        "collector_id": "collector-123456789012",
        "name": "Jenkins Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-jenkins-inven-collector",
        "version": "0.1.1"
        },
        "provider": "jenkins",
        "capability": {},
        "is_public": true
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T10:00:01.389Z",
        "updated_at": "2022-01-01T10:00:01.389Z",
        "finished_at": "2022-01-01T10:02:11.270Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Jobs. You can use a query to get a filtered list of Jobs.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "job_id": "job-3b124006c2d2",
        "status": "SUCCESS",
        "filter": {},
        "total_tasks": 2,
        "collector_info": {
        "collector_id": "collector-accd02663b3d",
        "name": "openstack-collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-openstack-inven-collector",
        "version": "0.4.2.20220616.134758"
        },
        "provider": "openstack",
        "capability": {
        "supported_schema": [
        "openstack_credentials"
        ]
        },
        "is_public": true
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-17T08:00:01.225Z",
        "updated_at": "2022-06-17T08:00:01.225Z",
        "finished_at": "2022-06-17T08:00:15.197Z"
        },
        {
        "job_id": "job-587a3d3b4db3",
        "status": "SUCCESS",
        "filter": {},
        "total_tasks": 3,
        "collector_info": {
        "collector_id": "collector-2c0847644f39",
        "name": "AWS stat-kwon Collector",
        "state": "ENABLED",
        "plugin_info": {
        "plugin_id": "plugin-30d21ef75a5d",
        "version": "1.13.13.20220610.143142"
        },
        "provider": "aws",
        "capability": {
        "supported_schema": [
        "aws_access_key"
        ]
        },
        "is_public": true
        },
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-17T08:00:00.407Z",
        "updated_at": "2022-06-17T08:00:00.407Z",
        "finished_at": "2022-06-17T08:07:32.023Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_JobServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.GetJobRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.JobInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobsQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.Job', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Job(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Job/delete',
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Job/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.GetJobRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_collector__pb2.JobInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Job/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobsQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Job/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_job__pb2.JobStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/resource_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0spaceone/api/inventory/v1/resource_history.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"F\n\x18ResourceHistoryReference\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x15\n\rexternal_link\x18\x02 \x01(\t\"?\n\x16ResourceHistoryRequest\x12\x12\n\nhistory_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"P\n\x19GetResourceHistoryRequest\x12\x12\n\nhistory_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x9b\x03\n\x14ResourceHistoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nhistory_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x05 \x01(\t\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x13\n\x0bregion_code\x18\n \x01(\t\x12\x12\n\nip_address\x18\x0b \x01(\t\x12\x19\n\x11resource_group_id\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x18\n\x10project_group_id\x18\x17 \x01(\t\x12\x11\n\tdomain_id\x18\x18 \x01(\t\x12\x18\n\x10\x63loud_service_id\x18\x19 \x01(\t\x12\x14\n\x0c\x63reated_date\x18\x1a \x01(\t\"\x81\x05\n\x13ResourceHistoryInfo\x12\x12\n\nhistory_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x04 \x01(\t\x12\x15\n\rinstance_type\x18\x05 \x01(\t\x12\x15\n\rinstance_size\x18\x06 \x01(\x02\x12\x1a\n\x12\x63loud_service_type\x18\x07 \x01(\t\x12\x1b\n\x13\x63loud_service_group\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12%\n\x04\x64\x61ta\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x46\n\treference\x18\r \x01(\x0b\x32\x33.spaceone.api.inventory.v1.ResourceHistoryReference\x12%\n\x04tags\x18\x0e \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x30\n\x0f\x63ollection_info\x18\x10 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x14\n\x0cip_addresses\x18\x11 \x03(\t\x12\x13\n\x0bregion_code\x18\x15 \x01(\t\x12\x12\n\nproject_id\x18\x16 \x01(\t\x12\x11\n\tdomain_id\x18\x17 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\x12\x12\n\ndeleted_at\x18! \x01(\t\x12\x18\n\x10\x63loud_service_id\x18\" \x01(\t\x12\x14\n\x0c\x63reated_date\x18# \x01(\t\"m\n\x15ResourceHistoriesInfo\x12?\n\x07results\x18\x01 \x03(\x0b\x32..spaceone.api.inventory.v1.ResourceHistoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"~\n\x18ResourceHistoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\"\x93\x01\n\x1bResourceHistoryCompareQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x19\n\x11resource_group_id\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\"H\n\x1fResourceHistoryBatchCreateQuery\x12\x12\n\nbatch_date\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa6\x06\n\x0fResourceHistory\x12\xa0\x01\n\x03get\x12\x34.spaceone.api.inventory.v1.GetResourceHistoryRequest\x1a..spaceone.api.inventory.v1.ResourceHistoryInfo\"3\x82\xd3\xe4\x93\x02-\x12+/inventory/v1/resource-history/{history_id}\x12\xbe\x01\n\x04list\x12/.spaceone.api.inventory.v1.ResourceHistoryQuery\x1a\x30.spaceone.api.inventory.v1.ResourceHistoriesInfo\"S\x82\xd3\xe4\x93\x02M\x12 /inventory/v1/resource-historiesZ)\"\'/inventory/v1/resource-histories/search\x12\x83\x01\n\x04stat\x12\x33.spaceone.api.inventory.v1.ResourceHistoryStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/inventory/v1/resource-histories/stat\x12\x8c\x01\n\x07\x63ompare\x12\x36.spaceone.api.inventory.v1.ResourceHistoryCompareQuery\x1a\x17.google.protobuf.Struct\"0\x82\xd3\xe4\x93\x02*\"(/inventory/v1/resource-histories/compare\x12\x99\x01\n\x0c\x62\x61tch_create\x12:.spaceone.api.inventory.v1.ResourceHistoryBatchCreateQuery\x1a\x16.google.protobuf.Empty\"5\x82\xd3\xe4\x93\x02/\"-/inventory/v1/resource-histories/batch_createb\x06proto3')



_RESOURCEHISTORYREFERENCE = DESCRIPTOR.message_types_by_name['ResourceHistoryReference']
_RESOURCEHISTORYREQUEST = DESCRIPTOR.message_types_by_name['ResourceHistoryRequest']
_GETRESOURCEHISTORYREQUEST = DESCRIPTOR.message_types_by_name['GetResourceHistoryRequest']
_RESOURCEHISTORYQUERY = DESCRIPTOR.message_types_by_name['ResourceHistoryQuery']
_RESOURCEHISTORYINFO = DESCRIPTOR.message_types_by_name['ResourceHistoryInfo']
_RESOURCEHISTORIESINFO = DESCRIPTOR.message_types_by_name['ResourceHistoriesInfo']
_RESOURCEHISTORYSTATQUERY = DESCRIPTOR.message_types_by_name['ResourceHistoryStatQuery']
_RESOURCEHISTORYCOMPAREQUERY = DESCRIPTOR.message_types_by_name['ResourceHistoryCompareQuery']
_RESOURCEHISTORYBATCHCREATEQUERY = DESCRIPTOR.message_types_by_name['ResourceHistoryBatchCreateQuery']
ResourceHistoryReference = _reflection.GeneratedProtocolMessageType('ResourceHistoryReference', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYREFERENCE,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryReference)
  })
_sym_db.RegisterMessage(ResourceHistoryReference)

ResourceHistoryRequest = _reflection.GeneratedProtocolMessageType('ResourceHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryRequest)
  })
_sym_db.RegisterMessage(ResourceHistoryRequest)

GetResourceHistoryRequest = _reflection.GeneratedProtocolMessageType('GetResourceHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETRESOURCEHISTORYREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetResourceHistoryRequest)
  })
_sym_db.RegisterMessage(GetResourceHistoryRequest)

ResourceHistoryQuery = _reflection.GeneratedProtocolMessageType('ResourceHistoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryQuery)
  })
_sym_db.RegisterMessage(ResourceHistoryQuery)

ResourceHistoryInfo = _reflection.GeneratedProtocolMessageType('ResourceHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryInfo)
  })
_sym_db.RegisterMessage(ResourceHistoryInfo)

ResourceHistoriesInfo = _reflection.GeneratedProtocolMessageType('ResourceHistoriesInfo', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORIESINFO,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoriesInfo)
  })
_sym_db.RegisterMessage(ResourceHistoriesInfo)

ResourceHistoryStatQuery = _reflection.GeneratedProtocolMessageType('ResourceHistoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYSTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryStatQuery)
  })
_sym_db.RegisterMessage(ResourceHistoryStatQuery)

ResourceHistoryCompareQuery = _reflection.GeneratedProtocolMessageType('ResourceHistoryCompareQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYCOMPAREQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryCompareQuery)
  })
_sym_db.RegisterMessage(ResourceHistoryCompareQuery)

ResourceHistoryBatchCreateQuery = _reflection.GeneratedProtocolMessageType('ResourceHistoryBatchCreateQuery', (_message.Message,), {
  'DESCRIPTOR' : _RESOURCEHISTORYBATCHCREATEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.resource_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.ResourceHistoryBatchCreateQuery)
  })
_sym_db.RegisterMessage(ResourceHistoryBatchCreateQuery)

_RESOURCEHISTORY = DESCRIPTOR.services_by_name['ResourceHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _RESOURCEHISTORY.methods_by_name['get']._options = None
  _RESOURCEHISTORY.methods_by_name['get']._serialized_options = b'\202\323\344\223\002-\022+/inventory/v1/resource-history/{history_id}'
  _RESOURCEHISTORY.methods_by_name['list']._options = None
  _RESOURCEHISTORY.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /inventory/v1/resource-historiesZ)\"\'/inventory/v1/resource-histories/search'
  _RESOURCEHISTORY.methods_by_name['stat']._options = None
  _RESOURCEHISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\'\"%/inventory/v1/resource-histories/stat'
  _RESOURCEHISTORY.methods_by_name['compare']._options = None
  _RESOURCEHISTORY.methods_by_name['compare']._serialized_options = b'\202\323\344\223\002*\"(/inventory/v1/resource-histories/compare'
  _RESOURCEHISTORY.methods_by_name['batch_create']._options = None
  _RESOURCEHISTORY.methods_by_name['batch_create']._serialized_options = b'\202\323\344\223\002/\"-/inventory/v1/resource-histories/batch_create'
  _RESOURCEHISTORYREFERENCE._serialized_start=202
  _RESOURCEHISTORYREFERENCE._serialized_end=272
  _RESOURCEHISTORYREQUEST._serialized_start=274
  _RESOURCEHISTORYREQUEST._serialized_end=337
  _GETRESOURCEHISTORYREQUEST._serialized_start=339
  _GETRESOURCEHISTORYREQUEST._serialized_end=419
  _RESOURCEHISTORYQUERY._serialized_start=422
  _RESOURCEHISTORYQUERY._serialized_end=833
  _RESOURCEHISTORYINFO._serialized_start=836
  _RESOURCEHISTORYINFO._serialized_end=1477
  _RESOURCEHISTORIESINFO._serialized_start=1479
  _RESOURCEHISTORIESINFO._serialized_end=1588
  _RESOURCEHISTORYSTATQUERY._serialized_start=1590
  _RESOURCEHISTORYSTATQUERY._serialized_end=1716
  _RESOURCEHISTORYCOMPAREQUERY._serialized_start=1719
  _RESOURCEHISTORYCOMPAREQUERY._serialized_end=1866
  _RESOURCEHISTORYBATCHCREATEQUERY._serialized_start=1868
  _RESOURCEHISTORYBATCHCREATEQUERY._serialized_end=1940
  _RESOURCEHISTORY._serialized_start=1943
  _RESOURCEHISTORY._serialized_end=2749
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/statistics/v1/history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/statistics/v1/history.proto\x12\x1aspaceone.api.statistics.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\">\n\x14\x43reateHistoryRequest\x12\x13\n\x0bschedule_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"c\n\x13QueryHistoryRequest\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"q\n\x10HistoryValueInfo\x12\r\n\x05topic\x18\x01 \x01(\t\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x12\n\ncreated_at\x18\x04 \x01(\t\"a\n\x0bHistoryInfo\x12=\n\x07results\x18\x01 \x03(\x0b\x32,.spaceone.api.statistics.v1.HistoryValueInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"l\n\x12HistoryStatRequest\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\r\n\x05topic\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t2\x96\x03\n\x07History\x12r\n\x06\x63reate\x12\x30.spaceone.api.statistics.v1.CreateHistoryRequest\x1a\x16.google.protobuf.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x16/statistics/v1/history\x12\xa0\x01\n\x04list\x12/.spaceone.api.statistics.v1.QueryHistoryRequest\x1a\'.spaceone.api.statistics.v1.HistoryInfo\">\x82\xd3\xe4\x93\x02\x38\x12\x16/statistics/v1/historyZ\x1e\"\x1c/statistics/v1/history/query\x12t\n\x04stat\x12..spaceone.api.statistics.v1.HistoryStatRequest\x1a\x17.google.protobuf.Struct\"#\x82\xd3\xe4\x93\x02\x1d\"\x1b/statistics/v1/history/statb\x06proto3')



_CREATEHISTORYREQUEST = DESCRIPTOR.message_types_by_name['CreateHistoryRequest']
_QUERYHISTORYREQUEST = DESCRIPTOR.message_types_by_name['QueryHistoryRequest']
_HISTORYVALUEINFO = DESCRIPTOR.message_types_by_name['HistoryValueInfo']
_HISTORYINFO = DESCRIPTOR.message_types_by_name['HistoryInfo']
_HISTORYSTATREQUEST = DESCRIPTOR.message_types_by_name['HistoryStatRequest']
CreateHistoryRequest = _reflection.GeneratedProtocolMessageType('CreateHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEHISTORYREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.CreateHistoryRequest)
  })
_sym_db.RegisterMessage(CreateHistoryRequest)

QueryHistoryRequest = _reflection.GeneratedProtocolMessageType('QueryHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUERYHISTORYREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.QueryHistoryRequest)
  })
_sym_db.RegisterMessage(QueryHistoryRequest)

HistoryValueInfo = _reflection.GeneratedProtocolMessageType('HistoryValueInfo', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYVALUEINFO,
  '__module__' : 'spaceone.api.statistics.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.HistoryValueInfo)
  })
_sym_db.RegisterMessage(HistoryValueInfo)

HistoryInfo = _reflection.GeneratedProtocolMessageType('HistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYINFO,
  '__module__' : 'spaceone.api.statistics.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.HistoryInfo)
  })
_sym_db.RegisterMessage(HistoryInfo)

HistoryStatRequest = _reflection.GeneratedProtocolMessageType('HistoryStatRequest', (_message.Message,), {
  'DESCRIPTOR' : _HISTORYSTATREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.HistoryStatRequest)
  })
_sym_db.RegisterMessage(HistoryStatRequest)

_HISTORY = DESCRIPTOR.services_by_name['History']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HISTORY.methods_by_name['create']._options = None
  _HISTORY.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\030\"\026/statistics/v1/history'
  _HISTORY.methods_by_name['list']._options = None
  _HISTORY.methods_by_name['list']._serialized_options = b'\202\323\344\223\0028\022\026/statistics/v1/historyZ\036\"\034/statistics/v1/history/query'
  _HISTORY.methods_by_name['stat']._options = None
  _HISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\035\"\033/statistics/v1/history/stat'
  _CREATEHISTORYREQUEST._serialized_start=195
  _CREATEHISTORYREQUEST._serialized_end=257
  _QUERYHISTORYREQUEST._serialized_start=259
  _QUERYHISTORYREQUEST._serialized_end=358
  _HISTORYVALUEINFO._serialized_start=360
  _HISTORYVALUEINFO._serialized_end=473
  _HISTORYINFO._serialized_start=475
  _HISTORYINFO._serialized_end=572
  _HISTORYSTATREQUEST._serialized_start=574
  _HISTORYSTATREQUEST._serialized_end=682
  _HISTORY._serialized_start=685
  _HISTORY._serialized_end=1091
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.notification.v1 import notification_usage_pb2 as spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2


class NotificationUsageStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.list = channel.unary_unary(
                '/spaceone.api.notification.v1.NotificationUsage/list',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2.NotificationUsageQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2.NotificationUsagesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.notification.v1.NotificationUsage/stat',
                request_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2.NotificationUsageStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class NotificationUsageServicer(object):
    """Missing associated documentation comment in .proto file."""

    def list(self, request, context):
        """
        desc: Gets a list of all NotificationUsages. You can use a query to get a filtered list of Notification Usages.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "protocol_id": "protocol-123456789012",
        "usage_date": "08",
        "usage_month": "2022-05",
        "count": 2,
        "domain_id": "domain-123456789012"
        },
        {
        "protocol_id": "protocol-123456789012",
        "usage_date": "18",
        "usage_month": "2022-05",
        "count": 7,
        "domain_id": "domain-123456789012"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotificationUsageServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2.NotificationUsageQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2.NotificationUsagesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2.NotificationUsageStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.notification.v1.NotificationUsage', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NotificationUsage(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.NotificationUsage/list',
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2.NotificationUsageQuery.SerializeToString,
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2.NotificationUsagesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.notification.v1.NotificationUsage/stat',
            spaceone_dot_api_dot_notification_dot_v1_dot_notification__usage__pb2.NotificationUsageStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/data_source.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.cost_analysis.v1 import job_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_job__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/spaceone/api/cost_analysis/v1/data_source.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a\'spaceone/api/cost_analysis/v1/job.proto\"\xd2\x02\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12)\n\x08metadata\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x11\n\tsecret_id\x18\x07 \x01(\t\x12K\n\x0cupgrade_mode\x18\x08 \x01(\x0e\x32\x35.spaceone.api.cost_analysis.v1.PluginInfo.UpgradeMode\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"\xf8\x02\n\x19RegisterDataSourceRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x61\n\x10\x64\x61ta_source_type\x18\x02 \x01(\x0e\x32G.spaceone.api.cost_analysis.v1.RegisterDataSourceRequest.DataSourceType\x12\x10\n\x08provider\x18\x03 \x01(\t\x12)\n\x08template\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12>\n\x0bplugin_info\x18\x05 \x01(\x0b\x32).spaceone.api.cost_analysis.v1.PluginInfo\x12%\n\x04tags\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"3\n\x0e\x44\x61taSourceType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\xa4\x01\n\x17UpdateDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x08template\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x94\x02\n\x1dUpdateDataSourcePluginRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12^\n\x0cupgrade_mode\x18\x04 \x01(\x0e\x32H.spaceone.api.cost_analysis.v1.UpdateDataSourcePluginRequest.UpgradeMode\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"-\n\x0bUpgradeMode\x12\x08\n\x04NONE\x10\x00\x12\n\n\x06MANUAL\x10\x01\x12\x08\n\x04\x41UTO\x10\x02\"k\n\x15SyncDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\r\n\x05start\x18\x02 \x01(\t\x12\x18\n\x10no_preload_cache\x18\x03 \x01(\x08\x12\x11\n\tdomain_id\x18\x0b \x01(\t\">\n\x11\x44\x61taSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"O\n\x14GetDataSourceRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\xa5\x02\n\x0f\x44\x61taSourceQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x16\n\x0e\x64\x61ta_source_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12W\n\x10\x64\x61ta_source_type\x18\x05 \x01(\x0e\x32=.spaceone.api.cost_analysis.v1.DataSourceQuery.DataSourceType\x12\x10\n\x08provider\x18\x06 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"3\n\x0e\x44\x61taSourceType\x12\x08\n\x04NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"\xe3\x04\n\x0e\x44\x61taSourceInfo\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x42\n\x05state\x18\x03 \x01(\x0e\x32\x33.spaceone.api.cost_analysis.v1.DataSourceInfo.State\x12V\n\x10\x64\x61ta_source_type\x18\x04 \x01(\x0e\x32<.spaceone.api.cost_analysis.v1.DataSourceInfo.DataSourceType\x12\x10\n\x08provider\x18\x05 \x01(\t\x12>\n\x0bplugin_info\x18\x06 \x01(\x0b\x32).spaceone.api.cost_analysis.v1.PluginInfo\x12)\n\x08template\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x15\n\rcost_tag_keys\x18\t \x03(\t\x12!\n\x19\x63ost_additional_info_keys\x18\n \x03(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x1c\n\x14last_synchronized_at\x18\x16 \x01(\t\"2\n\x05State\x12\x0e\n\nSTATE_NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"8\n\x0e\x44\x61taSourceType\x12\r\n\tTYPE_NONE\x10\x00\x12\t\n\x05LOCAL\x10\x01\x12\x0c\n\x08\x45XTERNAL\x10\x02\"f\n\x0f\x44\x61taSourcesInfo\x12>\n\x07results\x18\x01 \x03(\x0b\x32-.spaceone.api.cost_analysis.v1.DataSourceInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"^\n\x13\x44\x61taSourceStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xa2\x0e\n\nDataSource\x12\x9b\x01\n\x08register\x12\x38.spaceone.api.cost_analysis.v1.RegisterDataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"&\x82\xd3\xe4\x93\x02 \"\x1e/cost-analysis/v1/data-sources\x12\xa7\x01\n\x06update\x12\x36.spaceone.api.cost_analysis.v1.UpdateDataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"6\x82\xd3\xe4\x93\x02\x30\x1a./cost-analysis/v1/data-source/{data_source_id}\x12\xbb\x01\n\rupdate_plugin\x12<.spaceone.api.cost_analysis.v1.UpdateDataSourcePluginRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"=\x82\xd3\xe4\x93\x02\x37\x1a\x35/cost-analysis/v1/data-source/{data_source_id}/plugin\x12\x9f\x01\n\rverify_plugin\x12\x30.spaceone.api.cost_analysis.v1.DataSourceRequest\x1a\x16.google.protobuf.Empty\"D\x82\xd3\xe4\x93\x02>\"</cost-analysis/v1/data-source/{data_source_id}/plugin/verify\x12\xa8\x01\n\x06\x65nable\x12\x30.spaceone.api.cost_analysis.v1.DataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"=\x82\xd3\xe4\x93\x02\x37\x1a\x35/cost-analysis/v1/data-source/{data_source_id}/enable\x12\xaa\x01\n\x07\x64isable\x12\x30.spaceone.api.cost_analysis.v1.DataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\">\x82\xd3\xe4\x93\x02\x38\x1a\x36/cost-analysis/v1/data-source/{data_source_id}/disable\x12\x8e\x01\n\nderegister\x12\x30.spaceone.api.cost_analysis.v1.DataSourceRequest\x1a\x16.google.protobuf.Empty\"6\x82\xd3\xe4\x93\x02\x30*./cost-analysis/v1/data-source/{data_source_id}\x12\xa1\x01\n\x04sync\x12\x34.spaceone.api.cost_analysis.v1.SyncDataSourceRequest\x1a&.spaceone.api.cost_analysis.v1.JobInfo\";\x82\xd3\xe4\x93\x02\x35\"3/cost-analysis/v1/data-source/{data_source_id}/sync\x12\xa1\x01\n\x03get\x12\x33.spaceone.api.cost_analysis.v1.GetDataSourceRequest\x1a-.spaceone.api.cost_analysis.v1.DataSourceInfo\"6\x82\xd3\xe4\x93\x02\x30\x12./cost-analysis/v1/data-source/{data_source_id}\x12\xb7\x01\n\x04list\x12..spaceone.api.cost_analysis.v1.DataSourceQuery\x1a..spaceone.api.cost_analysis.v1.DataSourcesInfo\"O\x82\xd3\xe4\x93\x02I\x12\x1e/cost-analysis/v1/data-sourcesZ\'\"%/cost-analysis/v1/data-sources/search\x12\x80\x01\n\x04stat\x12\x32.spaceone.api.cost_analysis.v1.DataSourceStatQuery\x1a\x17.google.protobuf.Struct\"+\x82\xd3\xe4\x93\x02%\"#/cost-analysis/v1/data-sources/statb\x06proto3')



_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_REGISTERDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['RegisterDataSourceRequest']
_UPDATEDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourceRequest']
_UPDATEDATASOURCEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateDataSourcePluginRequest']
_SYNCDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['SyncDataSourceRequest']
_DATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['DataSourceRequest']
_GETDATASOURCEREQUEST = DESCRIPTOR.message_types_by_name['GetDataSourceRequest']
_DATASOURCEQUERY = DESCRIPTOR.message_types_by_name['DataSourceQuery']
_DATASOURCEINFO = DESCRIPTOR.message_types_by_name['DataSourceInfo']
_DATASOURCESINFO = DESCRIPTOR.message_types_by_name['DataSourcesInfo']
_DATASOURCESTATQUERY = DESCRIPTOR.message_types_by_name['DataSourceStatQuery']
_PLUGININFO_UPGRADEMODE = _PLUGININFO.enum_types_by_name['UpgradeMode']
_REGISTERDATASOURCEREQUEST_DATASOURCETYPE = _REGISTERDATASOURCEREQUEST.enum_types_by_name['DataSourceType']
_UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE = _UPDATEDATASOURCEPLUGINREQUEST.enum_types_by_name['UpgradeMode']
_DATASOURCEQUERY_DATASOURCETYPE = _DATASOURCEQUERY.enum_types_by_name['DataSourceType']
_DATASOURCEINFO_STATE = _DATASOURCEINFO.enum_types_by_name['State']
_DATASOURCEINFO_DATASOURCETYPE = _DATASOURCEINFO.enum_types_by_name['DataSourceType']
PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

RegisterDataSourceRequest = _reflection.GeneratedProtocolMessageType('RegisterDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.RegisterDataSourceRequest)
  })
_sym_db.RegisterMessage(RegisterDataSourceRequest)

UpdateDataSourceRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateDataSourceRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourceRequest)

UpdateDataSourcePluginRequest = _reflection.GeneratedProtocolMessageType('UpdateDataSourcePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEDATASOURCEPLUGINREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateDataSourcePluginRequest)
  })
_sym_db.RegisterMessage(UpdateDataSourcePluginRequest)

SyncDataSourceRequest = _reflection.GeneratedProtocolMessageType('SyncDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SYNCDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.SyncDataSourceRequest)
  })
_sym_db.RegisterMessage(SyncDataSourceRequest)

DataSourceRequest = _reflection.GeneratedProtocolMessageType('DataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceRequest)
  })
_sym_db.RegisterMessage(DataSourceRequest)

GetDataSourceRequest = _reflection.GeneratedProtocolMessageType('GetDataSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDATASOURCEREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetDataSourceRequest)
  })
_sym_db.RegisterMessage(GetDataSourceRequest)

DataSourceQuery = _reflection.GeneratedProtocolMessageType('DataSourceQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceQuery)
  })
_sym_db.RegisterMessage(DataSourceQuery)

DataSourceInfo = _reflection.GeneratedProtocolMessageType('DataSourceInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCEINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceInfo)
  })
_sym_db.RegisterMessage(DataSourceInfo)

DataSourcesInfo = _reflection.GeneratedProtocolMessageType('DataSourcesInfo', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourcesInfo)
  })
_sym_db.RegisterMessage(DataSourcesInfo)

DataSourceStatQuery = _reflection.GeneratedProtocolMessageType('DataSourceStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _DATASOURCESTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.data_source_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.DataSourceStatQuery)
  })
_sym_db.RegisterMessage(DataSourceStatQuery)

_DATASOURCE = DESCRIPTOR.services_by_name['DataSource']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DATASOURCE.methods_by_name['register']._options = None
  _DATASOURCE.methods_by_name['register']._serialized_options = b'\202\323\344\223\002 \"\036/cost-analysis/v1/data-sources'
  _DATASOURCE.methods_by_name['update']._options = None
  _DATASOURCE.methods_by_name['update']._serialized_options = b'\202\323\344\223\0020\032./cost-analysis/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['update_plugin']._options = None
  _DATASOURCE.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\0027\0325/cost-analysis/v1/data-source/{data_source_id}/plugin'
  _DATASOURCE.methods_by_name['verify_plugin']._options = None
  _DATASOURCE.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\002>\"</cost-analysis/v1/data-source/{data_source_id}/plugin/verify'
  _DATASOURCE.methods_by_name['enable']._options = None
  _DATASOURCE.methods_by_name['enable']._serialized_options = b'\202\323\344\223\0027\0325/cost-analysis/v1/data-source/{data_source_id}/enable'
  _DATASOURCE.methods_by_name['disable']._options = None
  _DATASOURCE.methods_by_name['disable']._serialized_options = b'\202\323\344\223\0028\0326/cost-analysis/v1/data-source/{data_source_id}/disable'
  _DATASOURCE.methods_by_name['deregister']._options = None
  _DATASOURCE.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\0020*./cost-analysis/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['sync']._options = None
  _DATASOURCE.methods_by_name['sync']._serialized_options = b'\202\323\344\223\0025\"3/cost-analysis/v1/data-source/{data_source_id}/sync'
  _DATASOURCE.methods_by_name['get']._options = None
  _DATASOURCE.methods_by_name['get']._serialized_options = b'\202\323\344\223\0020\022./cost-analysis/v1/data-source/{data_source_id}'
  _DATASOURCE.methods_by_name['list']._options = None
  _DATASOURCE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002I\022\036/cost-analysis/v1/data-sourcesZ\'\"%/cost-analysis/v1/data-sources/search'
  _DATASOURCE.methods_by_name['stat']._options = None
  _DATASOURCE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002%\"#/cost-analysis/v1/data-sources/stat'
  _PLUGININFO._serialized_start=247
  _PLUGININFO._serialized_end=585
  _PLUGININFO_UPGRADEMODE._serialized_start=540
  _PLUGININFO_UPGRADEMODE._serialized_end=585
  _REGISTERDATASOURCEREQUEST._serialized_start=588
  _REGISTERDATASOURCEREQUEST._serialized_end=964
  _REGISTERDATASOURCEREQUEST_DATASOURCETYPE._serialized_start=913
  _REGISTERDATASOURCEREQUEST_DATASOURCETYPE._serialized_end=964
  _UPDATEDATASOURCEREQUEST._serialized_start=967
  _UPDATEDATASOURCEREQUEST._serialized_end=1131
  _UPDATEDATASOURCEPLUGINREQUEST._serialized_start=1134
  _UPDATEDATASOURCEPLUGINREQUEST._serialized_end=1410
  _UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE._serialized_start=540
  _UPDATEDATASOURCEPLUGINREQUEST_UPGRADEMODE._serialized_end=585
  _SYNCDATASOURCEREQUEST._serialized_start=1412
  _SYNCDATASOURCEREQUEST._serialized_end=1519
  _DATASOURCEREQUEST._serialized_start=1521
  _DATASOURCEREQUEST._serialized_end=1583
  _GETDATASOURCEREQUEST._serialized_start=1585
  _GETDATASOURCEREQUEST._serialized_end=1664
  _DATASOURCEQUERY._serialized_start=1667
  _DATASOURCEQUERY._serialized_end=1960
  _DATASOURCEQUERY_DATASOURCETYPE._serialized_start=913
  _DATASOURCEQUERY_DATASOURCETYPE._serialized_end=964
  _DATASOURCEINFO._serialized_start=1963
  _DATASOURCEINFO._serialized_end=2574
  _DATASOURCEINFO_STATE._serialized_start=2466
  _DATASOURCEINFO_STATE._serialized_end=2516
  _DATASOURCEINFO_DATASOURCETYPE._serialized_start=2518
  _DATASOURCEINFO_DATASOURCETYPE._serialized_end=2574
  _DATASOURCESINFO._serialized_start=2576
  _DATASOURCESINFO._serialized_end=2678
  _DATASOURCESTATQUERY._serialized_start=2680
  _DATASOURCESTATQUERY._serialized_end=2774
  _DATASOURCE._serialized_start=2777
  _DATASOURCE._serialized_end=4603
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import cloud_service_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2


class CloudServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/create',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CreateServiceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/update',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.UpdateCloudServiceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/delete',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.GetCloudServiceRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServicesInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.allow_delete_stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.CloudService/allow_delete_stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class CloudServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new CloudService. A CloudService instance is created based on data including the `resource`'s attribute values. When creating, the classification information defined by CloudServiceType is also needed. The created CloudService has collection information which is the collection history for the `resource` by plugin.
        request_example: >-
        {
        "cloud_service_type": "Key",
        "provider": "aws",
        "cloud_service_group": "KMS",
        "name": "cloud_service_test",
        "account": "251340636361",
        "launched_at": "2020-08-03T15:00:54.000Z",
        "ip_addresses": [],
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {},
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "a": "b"
        },
        "region_code": "ap-northeast-1"
        }
        response_example: >-
        {
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test",
        "state": "ACTIVE",
        "account": "251340636361",
        "cloud_service_type": "Key",
        "cloud_service_group": "KMS",
        "provider": "aws",
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {
        "manual": {}
        },
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "a": "b"
        },
        "collection_info": {
        "collectors": [],
        "service_accounts": [],
        "secrets": []
        },
        "ip_addresses": [],
        "region_code": "ap-northeast-1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T06:38:48.989Z",
        "updated_at": "2022-06-22T06:38:48.989Z",
        "launched_at": "2020-08-03T15:00:54.000Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific CloudService. You can make changes in CloudService settings, except for the classification system of CloudService and the information about the `resource` attribute value.
        request_example: >-
        {
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test2",
        "ip_addresses": [
        "1.1.1.1",
        "2.2.2.2"
        ],
        "tags": {
        "description": "spaceone"
        },
        "region_code": "ap-northeast-2"
        }
        response_example: >-
        {
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test2",
        "state": "ACTIVE",
        "account": "251340636361",
        "cloud_service_type": "Key",
        "cloud_service_group": "KMS",
        "provider": "aws",
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {
        "manual": {}
        },
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "description": "spaceone"
        },
        "collection_info": {
        "collectors": [],
        "service_accounts": [],
        "secrets": []
        },
        "ip_addresses": [
        "1.1.1.1",
        "2.2.2.2"
        ],
        "region_code": "ap-northeast-1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T06:38:48.989Z",
        "updated_at": "2022-06-22T06:38:48.989Z",
        "launched_at": "2020-08-03T15:00:54.000Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific CloudService. You must specify the `cloud_service_id` of the CloudService to delete.
        request_example: >-
        {
        "cloud_service_id": "cloud-svc-fea2b0d32141"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific CloudService. Prints detailed information about the CloudService, including its state, classification information, and attribute values.
        request_example: >-
        {
        "cloud_service_id": "cloud-svc-fea2b0d32141"
        }
        response_example: >-
        {
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test2",
        "state": "ACTIVE",
        "account": "251340636361",
        "cloud_service_type": "Key",
        "cloud_service_group": "KMS",
        "provider": "aws",
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {
        "manual": {}
        },
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "description": "spaceone"
        },
        "collection_info": {
        "collectors": [],
        "service_accounts": [],
        "secrets": []
        },
        "ip_addresses": [
        "1.1.1.1",
        "2.2.2.2"
        ],
        "region_code": "ap-northeast-1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T06:38:48.989Z",
        "updated_at": "2022-06-22T06:38:48.989Z",
        "launched_at": "2020-08-03T15:00:54.000Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all CloudServices. You can use a query to get a filtered list of CloudServices.
        request_example: >-
        {
        "query": {
        "filter": [
        {
        "key": "cloud_service_type",
        "value": "Key",
        "operator": "eq"
        }
        ]
        }
        }
        response_example: >-
        {
        "results": [{
        "cloud_service_id": "cloud-svc-c00f38a173e1",
        "name": "cloud_service_test2",
        "state": "ACTIVE",
        "account": "251340636361",
        "cloud_service_type": "Key",
        "cloud_service_group": "KMS",
        "provider": "aws",
        "data": {
        "alias_arn": null,
        "origin": "AWS_KMS",
        "cloudwatch": {
        "region_name": "ap-northeast-1",
        "namespace": "AWS/KMS",
        "dimensions": [
        {
        "Value": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "Name": "KeyId"
        }
        ]
        },
        "aws_account_id": "251340636361",
        "creation_date": "2020-07-09T09:39:03.097000+0000",
        "encryption_algorithms": [
        "SYMMETRIC_DEFAULT"
        ],
        "key_usage": "ENCRYPT_DECRYPT",
        "key_id": "0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_type_path": "defaultKeys",
        "key_rotated": false,
        "description": "Default master key that protects my Secrets Manager data when no other key is defined",
        "key_state": "Enabled",
        "customer_master_key_spec": "SYMMETRIC_DEFAULT",
        "enabled": true,
        "arn": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "key_manager": "AWS"
        },
        "metadata": {
        "manual": {}
        },
        "reference": {
        "resource_id": "arn:aws:kms:ap-northeast-1:251340636361:key/0drda5e1-c40f-45d7-a647-xxxxxxx",
        "external_link": "https://console.aws.amazon.com/kms/home?region=ap-northeast-1#/kms/defaultKeys/0drda5e1-c40f-45d7-a647-xxxxxxx/"
        },
        "tags": {
        "description": "spaceone"
        },
        "collection_info": {
        "collectors": [],
        "service_accounts": [],
        "secrets": []
        },
        "ip_addresses": [
        "1.1.1.1",
        "2.2.2.2"
        ],
        "region_code": "ap-northeast-1",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-06-22T06:38:48.989Z",
        "updated_at": "2022-06-22T06:38:48.989Z",
        "launched_at": "2020-08-03T15:00:54.000Z"
        }],
        "total_count": 1
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def allow_delete_stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CloudServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CreateServiceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.UpdateCloudServiceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.GetCloudServiceRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServicesInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'allow_delete_stat': grpc.unary_unary_rpc_method_handler(
                    servicer.allow_delete_stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.CloudService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CloudService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/create',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CreateServiceRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/update',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.UpdateCloudServiceRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/delete',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.GetCloudServiceRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServicesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def allow_delete_stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.CloudService/allow_delete_stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_cloud__service__pb2.CloudServiceStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from spaceone.api.cost_analysis.v1 import exchange_rate_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2


class ExchangeRateStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.set = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.ExchangeRate/set',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.SetExchangeRateRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
                )
        self.reset = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.ExchangeRate/reset',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.ExchangeRate/enable',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.ExchangeRate/disable',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.ExchangeRate/get',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.ExchangeRate/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRatesInfo.FromString,
                )


class ExchangeRateServicer(object):
    """Missing associated documentation comment in .proto file."""

    def set(self, request, context):
        """
        desc: Overrides a value of a specific ExchangeRate. This method is used to change the ExchangeRate in a specific domain. You can set the `currency` and `rate` of the resource.
        request_example: >-
        {
        "currency": "KRW",
        "rate": 1300
        }
        response_example: >-
        {
        "currency": "KRW",
        "rate": 1300.0,
        "state": "ENABLED",
        "is_default": true
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def reset(self, request, context):
        """
        desc: Resets a value of a specific ExchangeRate and changes the ExchangeRate to the ExchangeRate of the `default` domain.
        request_example: >-
        {
        "currency": "KRW"
        }
        response_example: >-
        {
        "currency": "KRW",
        "rate": 1242.7,
        "state": "ENABLED",
        "is_default": true,
        "domain_id": "domain-58010aa2e451"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: ''
        request_example: >-
        {
        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: ''
        request_example: >-
        {

        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific ExchangeRate. Prints detailed information about the ExchangeRate, including  `currency` and `rate`.
        request_example: >-
        {
        "currency": "KRW"
        }
        response_example: >-
        {
        "currency": "KRW",
        "rate": 1242.7,
        "state": "ENABLED",
        "is_default": true,
        "domain_id": "domain-58010aa2e451"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all ExchangeRates. You can use a query to get a filtered list of ExchangeRates.
        request_example: >-
        {
        }
        response_example: >-
        {
        "results": [
        {
        "currency": "JPY",
        "rate": 129.8,
        "state": "ENABLED",
        "is_default": true,
        "domain_id": "domain-58010aa2e451"
        },
        {
        "currency": "KRW",
        "rate": 1242.7,
        "state": "ENABLED",
        "is_default": true,
        "domain_id": "domain-58010aa2e451"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ExchangeRateServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'set': grpc.unary_unary_rpc_method_handler(
                    servicer.set,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.SetExchangeRateRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.SerializeToString,
            ),
            'reset': grpc.unary_unary_rpc_method_handler(
                    servicer.reset,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRatesInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.ExchangeRate', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ExchangeRate(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def set(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.ExchangeRate/set',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.SetExchangeRateRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def reset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.ExchangeRate/reset',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.ExchangeRate/enable',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.ExchangeRate/disable',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.ExchangeRate/get',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.ExchangeRate/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRateQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_exchange__rate__pb2.ExchangeRatesInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import savings_recommendation_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2


class SavingsRecommendationStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsRecommendation/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.GetSavingsRecommendationRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsRecommendation/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.SavingsRecommendation/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class SavingsRecommendationServicer(object):
    """Missing associated documentation comment in .proto file."""

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SavingsRecommendationServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.GetSavingsRecommendationRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.SavingsRecommendation', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SavingsRecommendation(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsRecommendation/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.GetSavingsRecommendationRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsRecommendation/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.SavingsRecommendation/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_savings__recommendation__pb2.SavingsRecommendationStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
